@@ -11,11 +11,11 @@ my $red   = $gd->colorAllocate(127,  0,  0);
 
 #print "No colours: $black ", $gd->colorsTotal, "\n";
 
-my $text = <<EOSTR;
-Lorem ipsum dolor sit amet, consectetuer adipiscing elit, 
-sed diam nonummy nibh euismod tincidunt ut laoreet dolore 
-magna aliquam erat volutpat.
-EOSTR
+my $text = 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit, 
+sed diam 
+
+nonummy nibh euismod 
+tincidunt ut laoreet dolore magna aliquam erat volutpat.';
 
 my $wp = GD::Text::Wrap->new($gd,
     width       => 180,
@@ -28,10 +28,12 @@ $wp->set(align => 'left');
 $gd->rectangle($wp->get_bounds(10,10), $blue);
 $wp->draw(10,10);
 
+$wp->set(para_space => 5, preserve_nl => 1);
 $wp->set_font('cetus', 10);
 $wp->set(align => 'justified', line_space => 0);
 $gd->rectangle($wp->get_bounds(210,10), $blue);
 $wp->draw(210,10);
+$wp->set(para_space => 10, preserve_nl => 0);
 
 $wp->font_path('/usr/share/fonts/ttfonts');
 $wp->set_font(['Arialn', 'cetus'], 10);
@@ -39,6 +41,8 @@ $wp->set(align => 'right');
 $gd->rectangle($wp->get_bounds(10,120), $blue);
 $wp->draw(10,120);
 
+$text =~ tr/\n//d;
+$wp->set(text => $text);
 $wp->set(colour => $white, align => 'center', line_space => 2);
 $wp->set_font(gdMediumBoldFont, 12);
 $gd->filledRectangle($wp->get_bounds(210,120), $red);
